@@ -7,7 +7,11 @@ eval "$(conda shell.bash hook)"
 conda remove -q -n test-env --all || true
 
 # Create and activate conda environment for this test
-conda create -q -n test-env python=${PYTHON_VERSION} pytest pytest-cov
+BINDING=$(echo "$1" | tr '[:lower:]' '[:upper:]')
+QT_VERSION_VAR=${BINDING}_QT_VERSION
+if [ "${!QT_VERSION_VAR:0:3}" = "5.9" ]; then PYTESTQT_VERSION="=3.3.0"; fi  # pytest-qt >=4 doesn't support Qt >=5.9
+if [ "${PYTHON_VERSION}" = "3.6" ]; then PIP_VERSION="=21.3.1"; fi # pip >21.3.1 depends on the 'dataclasses' module (unavailable by default with Python 3.6)
+conda create -q -n test-env python=${PYTHON_VERSION} pytest 'pytest-cov>=3.0.0' pytest-qt${PYTESTQT_VERSION:-} pip${PIP_VERSION:-}
 conda activate test-env
 
 if [ "$USE_CONDA" = "Yes" ]; then
